==> apo-ws-client-6.00.10.4-sources.jar: fr/univlorraine/apowsclient/creationSE/CreerLSE.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="listeElementPedagogi" type="{ListeElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}ListeElementPedagogiDTO3" form="unqualified"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "listeElementPedagogi"
})
@XmlRootElement(name = "creerLSE", namespace = "gouv.education.apogee.commun.servicesmetiers.CreationSEMetier_17102019")
public class CreerLSE {

    @XmlElement(required = true)
    protected ListeElementPedagogiDTO3 listeElementPedagogi;

    /**
     * Obtient la valeur de la propriété listeElementPedagogi.
     * 
     * @return
     *     possible object is
     *     {@link ListeElementPedagogiDTO3 }
     *     
     */
    public ListeElementPedagogiDTO3 getListeElementPedagogi() {
        return listeElementPedagogi;
    }

    /**
     * Définit la valeur de la propriété listeElementPedagogi.
     * 
     * @param value
     *     allowed object is
     *     {@link ListeElementPedagogiDTO3 }
     *     
     */
    public void setListeElementPedagogi(ListeElementPedagogiDTO3 value) {
        this.listeElementPedagogi = value;
    }

}

==> apo-ws-client-6.00.51.2-sources.jar: fr/univlorraine/apowsclient/creationSE/CreerLSE.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="listeElementPedagogi" type="{ListeElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}ListeElementPedagogiDTO3" form="unqualified"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "listeElementPedagogi"
})
@XmlRootElement(name = "creerLSE", namespace = "gouv.education.apogee.commun.servicesmetiers.CreationSEMetier")
public class CreerLSE {

    @XmlElement(required = true)
    protected ListeElementPedagogiDTO3 listeElementPedagogi;

    /**
     * Obtient la valeur de la propriété listeElementPedagogi.
     * 
     * @return
     *     possible object is
     *     {@link ListeElementPedagogiDTO3 }
     *     
     */
    public ListeElementPedagogiDTO3 getListeElementPedagogi() {
        return listeElementPedagogi;
    }

    /**
     * Définit la valeur de la propriété listeElementPedagogi.
     * 
     * @param value
     *     allowed object is
     *     {@link ListeElementPedagogiDTO3 }
     *     
     */
    public void setListeElementPedagogi(ListeElementPedagogiDTO3 value) {
        this.listeElementPedagogi = value;
    }

}
